@@ -27,7 +27,7 @@ def make_distance_metrics(indel=False,
                           ssk=False,
                           refined_soundex=False,
                           double_metaphone=False) -> dict:
-    """
+    r"""
     A function which returns a dict containing the distance metrics that should be 
     used during the fuzzy string matching
 
@@ -93,9 +93,9 @@ def make_distance_metrics(indel=False,
         default=False
     iterative_sub_string: bool
         Boolean indicating whether the IterativeSubString method should be used 
-        during the fuzzy name matching. A method that counts the simularities 
-        between two strings substrings and substracts the differences taking into
-        acount the winkler similarity between the string and the substring.
+        during the fuzzy name matching. A method that counts the similarities 
+        between two strings substrings and subtracts the differences taking into
+        account the winkler similarity between the string and the substring.
         default=False
     baulieu_xiii: bool
         Boolean indicating whether the BaulieuXIII method should be used during 
@@ -153,7 +153,7 @@ def make_distance_metrics(indel=False,
         default=True
     ncd_bz2: bool
         Boolean indicating whether the NCDbz2 method should be used during the 
-        fuzzy name matching. Applies the Burrows-Wheeler transform to hte strings and 
+        fuzzy name matching. Applies the Burrows-Wheeler transform to the strings and 
         subsequently returns the normalised compression distance.
         default=False
     fuzzy_wuzzy_partial_string: bool
@@ -263,4 +263,4 @@ def make_distance_metrics(indel=False,
         distance_metrics['phonetic'].append(PhoneticDistance(
             transforms=DoubleMetaphone(max_length=30), metric=Levenshtein(), encode_alpha=True))
 
-    return distance_metrics
\ No newline at end of file
+    return distance_metrics
