@@ -17,14 +17,14 @@ class NameMatcher:
 
     """
     A class for the name matching of data based on the strings in a single column. The NameMatcher
-    first applies a cosine simularity on the ngrams of the strings to get an aproximate match followed 
+    first applies a cosine similarity on the ngrams of the strings to get an approximate match followed 
     by a fuzzy matching based on a number of different algorithms.
 
     Parameters
     ----------
     ngrams : tuple of integers
         The length of the ngrams which should be used for the generation of ngrams for the cosine
-        simularity comparrison of the possible matches
+        similarity comparison of the possible matches
         default=(2, 3)
     top_n : integer
         The number of possible matches that should be included in the group which will be analysed
@@ -36,10 +36,10 @@ class NameMatcher:
         default=False
     number_of_rows : integer
         Determines how many rows should be calculated at once with the sparse cosine similarity step.
-        If the low_memory bool is True this number is unsued.
+        If the low_memory bool is True this number is unused.
         default=5000
     number_of_matches : int
-        The number of matches which should be returned by the matching algroithm. If a number higher
+        The number of matches which should be returned by the matching algorithm. If a number higher
         than 1 is given, a number of alternative matches are also returned. If the number is equal
         to the number of algorithms used, the best match for each algorithm is returned. If the
         number is equal to the number of algorithm groups which are included the best match for each
@@ -50,11 +50,11 @@ class NameMatcher:
         the final score. The terms are still included in determining the best match.
         default=False
     common_words : bool
-        Boolean indicating whether the most common words from the matching datashould be excluded 
+        Boolean indicating whether the most common words from the matching data should be excluded 
         when calculating the final score. The terms are still included in determining the best match.
         default=False
     cut_off_no_scoring_words: float
-        the cut off percentage of the occurence of the most occuring word for which words are still included 
+        the cut off percentage of the occurrence of the most occurring word for which words are still included 
         in the no_soring_words set
         default=0.01
     lowercase : bool
@@ -69,7 +69,7 @@ class NameMatcher:
         ascii characters
         default=True : bool
     preprocess_split
-        Indicating whether during the preporcessing an additional step should be taken in which only 
+        Indicating whether during the preprocessing an additional step should be taken in which only 
         the most common words out of a name are isolated and used in the matching process. The removing 
         of the common words is only done for the n-grams cosine matching part.
         default=False
@@ -178,14 +178,13 @@ class NameMatcher:
         try:
             self._distance_metrics = make_distance_metrics(**input_metrics)
         except TypeError:
-            raise TypeError('Not all of the supplied distance metrics are avialable. Please check the' +
+            raise TypeError('Not all of the supplied distance metrics are available. Please check the' +
                             'list of options in the make_distance_metrics function and adjust your list accordingly')
         self._num_distance_metrics = sum(
             [len(x) for x in self._distance_metrics.values()])
 
-    def _select_top_words(self, word: str, word_counts: pd.Series, occurence_count: int) -> str:
-        """
-        Remove the top words from the string word based on an occurence_count threshold
+    def _select_top_words(self, word: str, word_counts: pd.Series, occurrence_count: int) -> str:
+        """Remove the top words from the string word based on an occurrence_count threshold
 
         Parameters
         ----------
@@ -193,8 +192,8 @@ class NameMatcher:
             the string from which the words should be removed
         word_counts: pd.Series
             the words which should be removed with their counts as result from a value_counts
-        occurence_count: int 
-            the multiplication factor of the minimum occurences below which to select 
+        occurrence_count: int 
+            the multiplication factor of the minimum occurrences below which to select 
 
         Returns
         -------
@@ -202,15 +201,14 @@ class NameMatcher:
            The string word with the words with a too high word_counts removed
         """
         compressed_list = list(compress(
-            word, (word_counts[word] < occurence_count*word_counts[word].min()).values))
+            word, (word_counts[word] < occurrence_count*word_counts[word].min()).values))
 
         return ' '.join(compressed_list)
 
     def _preprocess_reduce(self,
                            to_be_matched: pd.DataFrame,
-                           occurence_count: int = 3) -> pd.DataFrame:
-        """
-        Preprocesses and copies the data to obtain the data with reduced strings. The strings have all words
+                           occurrence_count: int = 3) -> pd.DataFrame:
+        """Preprocesses and copies the data to obtain the data with reduced strings. The strings have all words
         removed which appear more than 3x as often as the least common word in the string and returns an adjusted 
         copy of the input 
 
@@ -218,8 +216,8 @@ class NameMatcher:
         ----------
         to_be_matched: pd.DataFrame 
             A dataframe from which the most common words should be removed
-        occurence_count: int
-            The number of occurence a word can occur more then the least common word in the string for which it will
+        occurrence_count: int
+            The number of occurrence a word can occur more then the least common word in the string for which it will
             still be included in the process 
             default=3
 
@@ -236,7 +234,7 @@ class NameMatcher:
         to_be_matched_new = to_be_matched.copy()
         name = to_be_matched[self._column_matching].str.split()
         to_be_matched_new[self._column_matching] = name.apply(
-            lambda word: self._select_top_words(word, preprocess_common_words_inst, occurence_count))
+            lambda word: self._select_top_words(word, preprocess_common_words_inst, occurrence_count))
 
         return to_be_matched_new
 
@@ -245,8 +243,7 @@ class NameMatcher:
                                      df_matching_data: pd.DataFrame,
                                      start_processing: bool = True,
                                      transform: bool = True) -> None:
-        """
-        Load the matching data into the NameMatcher and start the preprocessing.
+        """Load the matching data into the NameMatcher and start the preprocessing.
 
         Parameters
         ----------
@@ -255,12 +252,11 @@ class NameMatcher:
         df_matching_data: pd.DataFrame
             The dataframe which is used to match the data to.
         start_processing : bool 
-            A boolean indicating wether to start the preprocessing step after loading the matching data 
+            A boolean indicating whether to start the preprocessing step after loading the matching data 
             default: True
         transform : bool 
-            A boolean indicating wether or not the data should be transformed after the vectoriser is initialised 
+            A boolean indicating whether or not the data should be transformed after the vectoriser is initialised 
             default: True
-
         """
         self._column = column
         self._df_matching_data = df_matching_data
@@ -269,16 +265,14 @@ class NameMatcher:
 
     def _process_matching_data(self,
                                transform: bool = True) -> None:
-        """
-        Function to process the matching data. Frst the matching data is perprocessed and assinged to 
+        """Function to process the matching data. First the matching data is preprocessed and assigned to 
         a variable within the NameMatcher. Next the data is used to initialise the TfidfVectorizer. 
 
         Parameters
         ----------
         transform : bool 
-            A boolean indicating wether or not the data should be transformed after the vectoriser is initialised 
+            A boolean indicating whether or not the data should be transformed after the vectoriser is initialised 
             default: True
-
         """
         self._df_matching_data = self.preprocess(
             self._df_matching_data, self._column)
@@ -291,10 +285,9 @@ class NameMatcher:
     def match_names(self,
                     to_be_matched: Union[pd.Series, pd.DataFrame],
                     column_matching: str) -> Union[pd.Series, pd.DataFrame]:
-        """
-        Performs the name matching operation on the to_be_matched data. First it does the preprocessing of the 
+        """Performs the name matching operation on the to_be_matched data. First it does the preprocessing of the 
         data to be matched as well as the matching data if this has not been performed. Subsequently based on 
-        ngrams a cosine simularity is computed between the matching data and the data to be matched, to the top n
+        ngrams a cosine similarity is computed between the matching data and the data to be matched, to the top n
         matches fuzzy matching algorithms are performed to determine the best match and the quality of the match
 
         Parameters
@@ -307,11 +300,10 @@ class NameMatcher:
         Returns
         -------
         Union[pd.Series, pd.DataFrame]
-            A series or dataframe depending on the input containg the match index from the matching_data dataframe. 
+            A series or dataframe depending on the input containing the match index from the matching_data dataframe. 
             the name in the to_be_matched data, the name to which the datapoint was matched and a score between 0 
             (no match) and 100(perfect match) to indicate the quality of the matches
         """
-
         if self._column == '':
             raise ValueError(
                 'Please first load the master data via the method: load_and_process_master_data')
@@ -357,9 +349,8 @@ class NameMatcher:
     def fuzzy_matches(self,
                       possible_matches: np.array,
                       to_be_matched: pd.Series) -> pd.Series:
-        """
-        A method which performs the fuzzy matching between the data in the to_be_matched series as well as
-        the indicated indexes of the matching_data points which are possible matching candidates.
+        """ A method which performs the fuzzy matching between the data in the to_be_matched series as well
+        as the indicated indexes of the matching_data points which are possible matching candidates.
 
         Parameters
         ----------
@@ -371,12 +362,10 @@ class NameMatcher:
         Returns
         -------
         pd.Series
-            A series containg the match index from the matching_data dataframe. the name in the to_be_matched data,
+            A series containing the match index from the matching_data dataframe. the name in the to_be_matched data,
             the name to which the datapoint was matched and a score between 0 (no match) and 100(perfect match) to 
             indicate the quality of the matches
-
         """
-
         if len(possible_matches.shape) > 1:
             possible_matches = possible_matches[0]
 
@@ -405,8 +394,7 @@ class NameMatcher:
     def _score_matches(self,
                        to_be_matched_instance: str,
                        possible_matches: list) -> np.array:
-        """
-        A method to score a name to_be_matched_instance to a list of possible matches. The scoring is done
+        """A method to score a name to_be_matched_instance to a list of possible matches. The scoring is done
         based on all the metrics which are enabled.
 
         Parameters
@@ -421,7 +409,6 @@ class NameMatcher:
         np.array
             The score of each of the matches with respect to the different metrics which are assessed.
         """
-
         match_score = np.zeros(
             (len(possible_matches), self._num_distance_metrics))
         idx = 0
@@ -435,22 +422,20 @@ class NameMatcher:
 
     def _rate_matches(self,
                       match_score: np.array) -> np.array:
-        """
-        Converts the match scores from the score_matches method to a list of indexes of the best scoring 
+        """Converts the match scores from the score_matches method to a list of indexes of the best scoring 
         matches limited to the _number_of_matches.
 
         Parameters
         ----------
         match_score : np.array
             An array containing the scores of each of the possible alternatives for each
-            of the differnet methods used
+            of the different methods used
 
         Returns
         -------
         np.array
             The indexes of the best rated matches
         """
-
         if self._number_of_matches == 1:
             ind = [np.argmax(np.mean(match_score, axis=1))]
         elif self._number_of_matches == len(self._distance_metrics):
@@ -470,8 +455,7 @@ class NameMatcher:
         return np.array(ind, dtype=int)
 
     def _get_alternative_names(self, match: pd.Series) -> list:
-        """
-        Gets all the possible match names from the match.
+        """Gets all the possible match names from the match.
 
         Parameters
         ----------
@@ -491,8 +475,7 @@ class NameMatcher:
         return alt_names
 
     def _process_words(self, org_name: str, alt_names: list) -> Tuple[str, list]:
-        """
-        Removes the words from the word list from the org_name and all the names in alt_names .
+        """Removes the words from the word list from the org_name and all the names in alt_names .
 
         Parameters
         ----------
@@ -517,8 +500,7 @@ class NameMatcher:
         return org_name, alt_names
 
     def _adjust_scores(self, match_score: np.array, match: pd.Series) -> pd.Series:
-        """
-        Adjust the scores to be between 0 and 100
+        """Adjust the scores to be between 0 and 100
 
         Parameters
         ----------
@@ -539,9 +521,8 @@ class NameMatcher:
 
     def postprocess(self,
                     match: pd.Series) -> pd.Series:
-        """
-        Postprocesses the scores to exclude certain specific company words or the most common words. In 
-        this method only the scores are adjusted, the matches still stand.
+        """Postprocesses the scores to exclude certain specific company words or the most 
+        common words. In this method only the scores are adjusted, the matches still stand.
 
         Parameters
         ----------
@@ -553,7 +534,6 @@ class NameMatcher:
         pd.Series
             A new version of the input series with updated scores
         """
-
         alt_names = self._get_alternative_names(match)
         org_name = str(match['original_name'])
 
@@ -567,29 +547,25 @@ class NameMatcher:
 
     def _vectorise_data(self,
                         transform: bool = True):
-        """
-        Initialises the TfidfVectorizer, which generates ngrams and weights them based on the occurance.
+        """Initialises the TfidfVectorizer, which generates ngrams and weights them based on the occurrance.
         Subsequently the matching data will be used to fit the vectoriser and the matching data might also be send
-        to the transform_data funtion depending on the transform boolean.
+        to the transform_data function depending on the transform boolean.
 
         Parameters
         ----------
         transform : bool 
-            A boolean indicating wether or not the data should be transformed after the vectoriser is initialised 
+            A boolean indicating whether or not the data should be transformed after the vectoriser is initialised 
             default: True
-
         """
         self._vec.fit(self._df_matching_data[self._column].values.flatten())
         if transform:
             self.transform_data()
 
     def transform_data(self):
-        """
-        A method which transforms the matching data based on the ngrams transformer. After the 
+        """A method which transforms the matching data based on the ngrams transformer. After the 
         transformation (the generation of the ngrams), the data is normalised by dividing each row
         by the sum of the row. Subsequently the data is changed to a coo sparse matrix format with
         the column indices in ascending order.
-
         """
         ngrams = self._vec.transform(
             self._df_matching_data[self._column].astype(str))
@@ -601,8 +577,7 @@ class NameMatcher:
 
     def _search_for_possible_matches(self,
                                      to_be_matched: pd.DataFrame) -> np.array:
-        """
-        Generates ngrams from the data which should be matched, calculate the cosine simularity
+        """Generates ngrams from the data which should be matched, calculate the cosine simularity
         between these data and the matching data. Hereafter a top n of the matches is selected and
         returned.
 
@@ -616,7 +591,6 @@ class NameMatcher:
         np.array
             An array of top n values which are most closely matched to the to be matched data based
             on the ngrams
-
         """
         if self._n_grams_matching is None:
             raise RuntimeError(
@@ -641,8 +615,7 @@ class NameMatcher:
     def preprocess(self,
                    df: pd.DataFrame,
                    column_name: str) -> pd.DataFrame:
-        """
-        Preprocess a dataframe before applying a name matching algorithm. The preprocessing consists of 
+        """Preprocess a dataframe before applying a name matching algorithm. The preprocessing consists of 
         removing special characters, spaces, converting all characters to lower case and removing the
         words given in the word lists
 
@@ -657,9 +630,7 @@ class NameMatcher:
         -------
         pd.DataFrame
             The preprocessed dataframe or series depending on the input
-
         """
-
         df.loc[:, column_name] = df[column_name].astype(str)
         if self._preprocess_lowercase:
             df.loc[:, column_name] = df[column_name].str.lower()
@@ -675,8 +646,7 @@ class NameMatcher:
         return df
 
     def _preprocess_word_list(self, terms: dict) -> list:
-        """
-        Preprocess legal words to remove punctuations and trailing leading space
+        """Preprocess legal words to remove punctuations and trailing leading space
 
         Parameters
         -------
@@ -687,7 +657,6 @@ class NameMatcher:
         -------
         list
             A list of preprocessed legal words  
-
         """
         if self._preprocess_punctuations:
             return [re.sub(r'[^\w\s]', '', s).strip() for s in functools.reduce(
@@ -697,8 +666,7 @@ class NameMatcher:
                     operator.iconcat, terms.values(), [])]
 
     def _process_legal_words(self, word_set: set) -> set:
-        """
-        Preprocess legal words and add them to the word_set
+        """Preprocess legal words and add them to the word_set
 
         Parameters
         -------
@@ -709,7 +677,6 @@ class NameMatcher:
         -------
         Set
             The original word_set with the legal words added
-
         """
         terms_type = self._preprocess_word_list(terms_by_type)
         terms_country = self._preprocess_word_list(terms_by_country)
@@ -718,22 +685,20 @@ class NameMatcher:
         return word_set
 
     def _process_common_words(self, word_set: set, cut_off: float) -> set:
-        """
-        A method to select the most common words from the matching_data.
+        """A method to select the most common words from the matching_data.
 
         Parameters
         -------
         word_set: str
             the current word list which should be extended with additional words  
         cut_off: float
-            the cut_off percentage of the occurence of the most occuring word for which words are still included 
+            the cut_off percentage of the occurrence of the most occurring word for which words are still included 
             in the no_soring_words set
 
         Returns
         -------
         Set
             The current word set with the most common words from the matching_data added
-
         """
         word_counts = self._df_matching_data[self._column].str.split(
             expand=True).stack().value_counts()
@@ -746,8 +711,7 @@ class NameMatcher:
                                indicator: str,
                                word_set: set,
                                cut_off: float) -> set:
-        """
-        A method to make a set of words which are not taken into account when scoring matches.
+        """A method to make a set of words which are not taken into account when scoring matches.
 
         Parameters
         -------
@@ -757,16 +721,14 @@ class NameMatcher:
         word_set: str
             the current word list which should be extended with additional words  
         cut_off: float
-            the cut_off percentage of the occurence of the most occuring word for which words are still included 
+            the cut_off percentage of the occurrence of the most occurring word for which words are still included 
             in the no_soring_words set
 
         Returns
         -------
         Set
             The set of no scoring words
-
         """
-
         if indicator == 'legal':
             word_set = self._process_legal_words(word_set)
         if indicator == 'common':
